Learn R Programming

robmixglm (version 1.2-5)

outlierTest: Test for the presence of outliers.

Description

Uses the parametric bootstrap to test for the presence of outliers.

Usage

outlierTest(object,  R = 999,  cores  =  max(detectCores() %/% 2,  1))

Value

An outlierTest object which is the object of class “boot” returned by the call to boot.

Arguments

object

A robmixglm object with a mixture (robust) random effects distribution.

R

number of bootstrap replications

cores

Number of cores to be used in parallel. Default is one less than available.

Author

Ken Beath <ken.beath@mq.edu.au>

Details

Performs a parametric bootstrap to compare models with and without outliers.

Examples

Run this code
# \donttest{
hospcosts.robustmix <- robmixglm(costs~adm+age+dest+ins+loglos+sex, family = "gamma", 
    data = hospcosts, cores = 1)
summary(hospcosts.robustmix)
summary(outlierTest(hospcosts.robustmix,  cores  =  1))
# }

Run the code above in your browser using DataLab