outlierTestMix.robmixglm: Test for the presence of outliers.

View source: R/outlierTestMix.robmixglm.R

outlierTestMixR Documentation

Test for the presence of outliers.

Description

Uses the parametric bootstrap to test for the presence of outliers.

Usage

outlierTestMix(object,  R = 999,  cores  =  max(detectCores(logical = FALSE)-1, 1))

Arguments

object

A robmixglm object with a mixture (robust) random effects distribution.

R

number of bootstrap replications

cores

Number of cores to be used in parallel. Default is one less than available.

Details

Performs a parametric bootstrap to compare models with and without outliers.

Value

An outlierTest object which is the object of class “boot” returned by the call to boot.

Author(s)

Ken Beath <ken.beath@mq.edu.au>

Examples


# note that I have used cores=1 to allow testing
# in practice this should be removed to use the default
hospcosts.robustmix <- robmixglm(costs~adm+age+dest+ins+loglos+sex, family = "gamma", 
    data = hospcosts, cores = 1)
summary(hospcosts.robustmix)
# note that I have used cores=1 to allow testing
# in practice this should be removed to use the default
summary(outlierTestMix(hospcosts.robustmix,  cores  =  1))

robmixglm documentation built on Oct. 4, 2026, 9:06 a.m.