Learn R Programming

robmixglm (version 1.2-5)

residuals.robmixglm: Extract Model Residuals

Description

Extracts model residuals from objects returned by modeling functions.

Usage

# S3 method for robmixglm
residuals(object,  type  =  c("deviance",  "pearson"),  ...)

Value

Residuals extracted from the object object.

Arguments

object

an object for which the extraction of model residuals is meaningful.

type

Type of residual where valid types are deviance and pearson.

...

other arguments.

Examples

Run this code
# \donttest{
library(MASS)
data(forbes)
forbes.robustmix <- robmixglm(bp~pres, data = forbes, cores = 1)
BIC(forbes.robustmix)
plot(fitted(forbes.robustmix), residuals(forbes.robustmix))
# }

Run the code above in your browser using DataLab