powered by
Extracts model residuals from objects returned by modeling functions.
# S3 method for robmixglm residuals(object, type = c("deviance", "pearson"), ...)
Residuals extracted from the object object.
object
an object for which the extraction of model residuals is meaningful.
Type of residual where valid types are deviance and pearson.
other arguments.
# \donttest{ library(MASS) data(forbes) forbes.robustmix <- robmixglm(bp~pres, data = forbes, cores = 1) BIC(forbes.robustmix) plot(fitted(forbes.robustmix), residuals(forbes.robustmix)) # }
Run the code above in your browser using DataLab